.. gyroid documentation master file, created by
   sphinx-quickstart on Fri Mar 23 14:23:06 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gyroid's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 4

   gyroid


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

